@@ -1,6 +1,7 @@
 import time
-from string import Template
 import datetime
+
+import jinja2
 import yaml
 from dbstream import DBStream
 from tabulate import tabulate
@@ -34,8 +35,7 @@ class DataSource:
     def __init__(self, dbstream: DBStream, path_to_datasource_folder,
                  schema_prefix=None,
                  layer_type='datasource',
-                 loader_function=None,
-                 update_schema_name_with_env=True):
+                 loader_function=None):
         """
 
         :param dbstream:
@@ -46,7 +46,7 @@ class DataSource:
         self.schema_prefix = schema_prefix
         self.layer_type = layer_type
         self.loader_function = loader_function
-        self.update_schema_name_with_env = update_schema_name_with_env
+        self.jinja_env = jinja2.Environment()
 
     def _build_folder_path(self, layer_name):
         return self.path_to_datasource_folder + 'layers/' + layer_name + "/"
@@ -105,7 +105,6 @@ class DataSource:
             query_template_file_name = query
         query_path = folder_path + "query/" + query_template_file_name + ".sql"
         query_params = query_config.get("query_params")
-        query_template = Template(self.load_file(query_path))
         table_name = query
         dict_params = dict()
         dict_params["TABLE_NAME"] = "%s.%s" % (schema_name, table_name)
@@ -120,7 +119,7 @@ class DataSource:
                         value = value["production"]
                 if value == "now":
                     value = "'" + str(datetime.datetime.now())[:10] + "'"
-                dict_params.update({params.upper(): value})
+                dict_params.update({params: value})
         dict_params.update(
             treat_all_snippet(
                 datasource_instance=self,
@@ -128,8 +127,8 @@ class DataSource:
                 layer=layer_name,
                 dict_params=dict_params)
         )
-        filled_query = query_template.substitute(dict_params)
-        return filled_query
+        template = self.jinja_env.from_string(self.load_file(query_path))
+        return template.render(dict_params)
 
     def compute(self, layer_name, query_name=None, environment="production", comparison_test=True):
         query_list, queries_config, schema_name, folder_path = self._get_query_list(
@@ -139,16 +138,11 @@ class DataSource:
 
         for query in query_list:
             log_info("Layer: %s | Query started: %s | Environment: %s" % (layer_name, query, environment))
-            schema_name_filled_query = schema_name
-            if self.update_schema_name_with_env:
-                schema_name_filled_query = schema_name if environment == 'production' else (
-                        schema_name + "_" + environment
-                )
             filled_query = self._filled_query(
                 queries_config=queries_config,
                 query=query,
                 folder_path=folder_path,
-                schema_name=schema_name_filled_query,
+                schema_name=schema_name if environment == 'production' else (schema_name + "_" + environment),
                 layer_name=layer_name,
                 environment=environment
             )
@@ -163,7 +157,7 @@ class DataSource:
             try:
                 self.dbstream.execute_query(filled_query)
             except Exception as e:
-                if "schema" in str(e):
+                if "schema" in str(e).lower() or "dataset" in str(e).lower():
                     self.dbstream.create_schema(destination_tables_with_schema[environment].split(".")[0])
                     self.dbstream.execute_query(filled_query)
                 else:
